![pytest](https://github.com/MetOffice/tempest_helper/workflows/pytest/badge.svg)

# tempest_helper
A Python module for the easier manipulation of TempestExtremes data

Documentation is temporarily available from https://metoffice.github.io/tempest_helper/
